import { defineComponent } from 'vue';
import * as common from 'schema-based-json-editor';
export * from 'schema-based-json-editor';
import { Editor } from './editor';
export { ArrayEditor } from './array-editor';
export { ObjectEditor } from './object-editor';
import { indexTemplateHtml } from './variables';
/**
 * @public
 */
export var JSONEditor = defineComponent({
    render: indexTemplateHtml,
    components: {
        editor: Editor
    },
    props: {
        schema: {
            type: Object,
            required: true,
        },
        initialValue: null,
        theme: String,
        icon: String,
        locale: Object,
        readonly: Boolean,
        dragula: Function,
        markdownit: Function,
        hljs: Object,
        forceHttps: Boolean,
        disableCollapse: Boolean,
        noSelect2: Boolean,
        minItemCountIfNeedFilter: Number,
        monacoEditor: Object,
    },
    computed: {
        themeObject: function () {
            return common.getTheme(this.theme);
        },
        localeObject: function () {
            return common.getLocale(this.locale);
        },
        iconObject: function () {
            return common.getIcon(this.icon, this.localeObject);
        },
        md: function () {
            return common.initializeMarkdown(this.markdownit, this.hljs, this.forceHttps);
        },
    },
    methods: {
        getReference: function (name) {
            if (this.schema.definitions) {
                return this.schema.definitions[name.substring('#/definitions/'.length)];
            }
            return undefined;
        },
        updateValue: function (value) {
            this.$emit('update-value', value);
        },
    },
});
